@@ -17,8 +17,10 @@ def get_user_activities(self, **params) -> ActivitiesResponse:
     """
     self._check_authorization()
     return self._make_request(
-        "GET", endpoint=f"https://{Configs.YAY_STAGING_HOST_2}/api/user_activities",
-        params=params, data_type=ActivitiesResponse
+        "GET",
+        endpoint=f"https://{Configs.YAY_STAGING_HOST_2}/api/user_activities",
+        params=params,
+        data_type=ActivitiesResponse,
     )
 
 
@@ -33,8 +35,10 @@ def get_user_merged_activities(self, **params) -> ActivitiesResponse:
     """
     self._check_authorization()
     return self._make_request(
-        "GET", endpoint=f"https://{Configs.YAY_STAGING_HOST_2}/api/v2/user_activities",
-        params=params, data_type=ActivitiesResponse
+        "GET",
+        endpoint=f"https://{Configs.YAY_STAGING_HOST_2}/api/v2/user_activities",
+        params=params,
+        data_type=ActivitiesResponse,
     )
 
 
@@ -42,10 +46,7 @@ def received_notification(self, pid: str, type: str, opened_at: int = None):
     # TODO: opened_atはnullalbeか確認する
     self._check_authorization()
     return self._make_request(
-        "POST", endpoint=f"{self.host}/api/received_push_notifications",
-        payload={
-            "pid": pid,
-            "type": type,
-            "opened_at": opened_at
-        }
+        "POST",
+        endpoint=f"{self.host}/api/received_push_notifications",
+        payload={"pid": pid, "type": type, "opened_at": opened_at},
     )
