@@ -10,20 +10,12 @@ from ..utils import *
 
 def create_review(self, user_id: int, comment: str):
     self._check_authorization()
-    timestamp = int(datetime.now().timestamp())
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.USERS_V2}/reviews/{user_id}",
-        payload={
-            "comment": comment,
-            "uuid": self.uuid,
-            "api_key": self.api_key,
-            "timestamp": timestamp,
-            "signed_info": signed_info_calculating(
-                self.uuid, timestamp, shared_key=True
-            ),
-        },
+        "POST",
+        endpoint=f"{Endpoints.USERS_V1}/reviews/{user_id}",
+        payload={"comment": comment},
     )
-    self.logger.info("Review created.")
+    self.logger.info(f"Review has been sent to {user_id}.")
     return response
 
 
@@ -31,7 +23,8 @@ def create_reviews(self, user_ids: List[int], comment: str):
     self._check_authorization()
     timestamp = int(datetime.now().timestamp())
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.USERS_V1}/reviews",
+        "POST",
+        endpoint=f"{Endpoints.USERS_V1}/reviews",
         payload={
             "user_ids": user_ids,
             "comment": comment,
@@ -43,17 +36,18 @@ def create_reviews(self, user_ids: List[int], comment: str):
             ),
         },
     )
-    self.logger.info("Reviews created.")
+    self.logger.info("Reviews have been sent to multiple users.")
     return response
 
 
 def delete_reviews(self, review_ids: List[int]):
     self._check_authorization()
     response = self._make_request(
-        "DELETE", endpoint=f"{Endpoints.USERS_V1}/reviews",
-        params={"review_ids[]": review_ids}
+        "DELETE",
+        endpoint=f"{Endpoints.USERS_V1}/reviews",
+        params={"review_ids[]": review_ids},
     )
-    self.logger.info("Reviews deleted.")
+    self.logger.info("Reviews have been deleted.")
     return response
 
 
@@ -69,8 +63,10 @@ def get_my_reviews(self, **params) -> ReviewsResponse:
     """
     self._check_authorization()
     return self._make_request(
-        "GET", endpoint=f"{Endpoints.USERS_V1}/reviews/mine",
-        params=params, data_type=ReviewsResponse
+        "GET",
+        endpoint=f"{Endpoints.USERS_V1}/reviews/mine",
+        params=params,
+        data_type=ReviewsResponse,
     )
 
 
@@ -86,16 +82,17 @@ def get_reviews(self, user_id: int, **params) -> ReviewsResponse:
 
     """
     return self._make_request(
-        "GET", endpoint=f"{Endpoints.USERS_V1}/reviews/{user_id}",
-        params=params, data_type=ReviewsResponse
+        "GET",
+        endpoint=f"{Endpoints.USERS_V1}/reviews/{user_id}",
+        params=params,
+        data_type=ReviewsResponse,
     )
 
 
 def pin_review(self, review_id: int):
     self._check_authorization()
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.PINNED_V1}/reviews",
-        payload={"id": review_id}
+        "POST", endpoint=f"{Endpoints.PINNED_V1}/reviews", payload={"id": review_id}
     )
     self.logger.info("Pinned the review.")
     return response
@@ -106,5 +103,5 @@ def unpin_review(self, review_id: int):
     response = self._make_request(
         "DELETE", endpoint=f"{Endpoints.PINNED_V1}/reviews{review_id}"
     )
-    self.logger.info("Review unpinned.")
+    self.logger.info("Unpinned the review.")
     return response
