@@ -11,51 +11,49 @@ from ..utils import *
 def add_post_to_thread(self, post_id: int, thread_id: int) -> ThreadInfo:
     self._check_authorization()
     response = self._make_request(
-        "PUT", endpoint=f"{Endpoints.POSTS_V3}/{post_id}/move_to_thread/{thread_id}",
-        data_type=ThreadInfo
+        "PUT",
+        endpoint=f"{Endpoints.POSTS_V3}/{post_id}/move_to_thread/{thread_id}",
+        data_type=ThreadInfo,
     )
-    self.logger.info("Post added to the thread.")
+    self.logger.info(f"Post '{post_id}' added to the thread '{thread_id}'.")
     return response
 
 
 def convert_post_to_thread(
-        self,
-        post_id: int,
-        title: str = None,
-        thread_icon_filename: str = None
+    self, post_id: int, title: str = None, thread_icon_filename: str = None
 ) -> ThreadInfo:
     self._check_authorization()
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.POSTS_V3}/{post_id}/move_to_thread",
-        payload={
-            "title": title,
-            "thread_icon_filename": thread_icon_filename
-        }, data_type=ThreadInfo
+        "POST",
+        endpoint=f"{Endpoints.POSTS_V3}/{post_id}/move_to_thread",
+        payload={"title": title, "thread_icon_filename": thread_icon_filename},
+        data_type=ThreadInfo,
     )
-    self.logger.info("Post converted to a thread.")
+    self.logger.info("Post has been converted to a thread.")
     return response
 
 
 def create_thread(
-        self,
-        group_id: int,
-        title: str,
-        thread_icon_filename: str
+    self, group_id: int, title: str, thread_icon_filename: str
 ) -> ThreadInfo:
     self._check_authorization()
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.THREADS_V1}",
+        "POST",
+        endpoint=f"{Endpoints.THREADS_V1}",
         payload={
             "group_id": group_id,
             "title": title,
             "thread_icon_filename": thread_icon_filename,
-        }, data_type=ThreadInfo
+        },
+        data_type=ThreadInfo,
     )
-    self.logger.info("Thread created.")
+    self.logger.info("A new thread has been created.")
     return response
 
 
-def get_group_thread_list(self, group_id: int, from_str: str = None, **params) -> GroupThreadListResponse:
+def get_group_thread_list(
+    self, group_id: int, from_str: str = None, **params
+) -> GroupThreadListResponse:
     """
 
     Parameters:
@@ -70,20 +68,23 @@ def get_group_thread_list(self, group_id: int, from_str: str = None, **params) -
     if from_str:
         params["from"] = from_str
     return self._make_request(
-        "GET", endpoint=f"{Endpoints.THREADS_V1}",
-        params=params, data_type=GroupThreadListResponse
+        "GET",
+        endpoint=f"{Endpoints.THREADS_V1}",
+        params=params,
+        data_type=GroupThreadListResponse,
     )
 
 
 def get_thread_joined_statuses(self, ids: List[int]) -> dict:
     self._check_authorization()
     return self._make_request(
-        "GET", endpoint=f"{Endpoints.THREADS_V1}/joined_statuses",
-        params={"ids[]": ids}
+        "GET", endpoint=f"{Endpoints.THREADS_V1}/joined_statuses", params={"ids[]": ids}
     )
 
 
-def get_thread_posts(self, thread_id: int, from_str: str = None, **params) -> PostsResponse:
+def get_thread_posts(
+    self, thread_id: int, from_str: str = None, **params
+) -> PostsResponse:
     """
 
     Parameters:
@@ -97,24 +98,28 @@ def get_thread_posts(self, thread_id: int, from_str: str = None, **params) -> Po
     if from_str:
         params["from"] = from_str
     return self._make_request(
-        "GET", endpoint=f"{Endpoints.THREADS_V1}/{thread_id}/posts",
-        params=params, data_type=PostsResponse
+        "GET",
+        endpoint=f"{Endpoints.THREADS_V1}/{thread_id}/posts",
+        params=params,
+        data_type=PostsResponse,
     )
 
 
 def join_thread(self, thread_id: int, user_id: int):
     self._check_authorization()
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.THREADS_V1}/{thread_id}/members/{user_id}",
+        "POST",
+        endpoint=f"{Endpoints.THREADS_V1}/{thread_id}/members/{user_id}",
     )
-    self.logger.info("Joined the thread.")
+    self.logger.info(f"Joined the thread '{thread_id}'.")
     return response
 
 
 def leave_thread(self, thread_id: int, user_id: int):
     self._check_authorization()
     response = self._make_request(
-        "DELETE", endpoint=f"{Endpoints.THREADS_V1}/{thread_id}/members/{user_id}",
+        "DELETE",
+        endpoint=f"{Endpoints.THREADS_V1}/{thread_id}/members/{user_id}",
     )
     self.logger.info("Left the thread.")
     return response
@@ -123,22 +128,19 @@ def leave_thread(self, thread_id: int, user_id: int):
 def remove_thread(self, thread_id: int):
     self._check_authorization()
     response = self._make_request(
-        "DELETE", endpoint=f"{Endpoints.THREADS_V1}/{thread_id}",
+        "DELETE",
+        endpoint=f"{Endpoints.THREADS_V1}/{thread_id}",
     )
-    self.logger.info("Thread removed.")
+    self.logger.info(f"Thread '{thread_id}' has been removed.")
     return response
 
 
-def update_thread(
-        self,
-        thread_id: int,
-        title: str,
-        thread_icon_filename: str
-):
+def update_thread(self, thread_id: int, title: str, thread_icon_filename: str):
     self._check_authorization()
     response = self._make_request(
-        "PUT", endpoint=f"{Endpoints.THREADS_V1}/{thread_id}",
-        payload={"title": title, "thread_icon_filename": thread_icon_filename}
+        "PUT",
+        endpoint=f"{Endpoints.THREADS_V1}/{thread_id}",
+        payload={"title": title, "thread_icon_filename": thread_icon_filename},
     )
-    self.logger.info("Thread updated.")
+    self.logger.info(f"Thread '{thread_id}' has been updated.")
     return response
